Struct Alias

pub struct Alias<'m> { /* private fields */ }
The details of a type alias.

Implementations

Source

impl<'m> Alias<'m>

pub fn parameters(&self) -> &Generics

The generic parameters required for this type alias.
For example, this item has two type parameters:

struct Either<A, B> {
    A(Box<A>),
    B(Box<B>),
}

But reusing these parameters on the alias to the type in variant A will fail, as parameter B is unused by the aliased type:

type Alias<A, B> = Box<A>;
type parameter `B` is unused

This method returns only the generic parameters used by the alias.

pub fn path_segment_no_parameters(&self) -> PathSegment

Returns this alias formatted as a PathSegment, without generic parameters

pub fn path_segment(&self) -> PathSegment

Returns this alias formatted as a PathSegment, with unsubstituted generic arguments if applicable.

pub fn aliased_type(&self) -> &Type

The original type being aliased

pub fn aliased_type_arguments( &self, ) -> Option<&Punctuated<GenericArgument, Comma>>

The type arguments on the original aliased type.
e.g. i32, u64 for my_crate::MyType<i32, i64>

pub fn path(&self) -> Path

Creates a qualified Path to the alias with no generic arguments

pub fn type_path(&self) -> TypePath

Creates a qualified TypePath to the alias, with generic arguments.

pub fn ty(&self) -> Type

Creates a qualified Type of the alias.